@@ -622,15 +622,7 @@ class PGTestCase(unittest.TestCase):
 
         result = self.cursor.execute("select s from t1").fetchone()[0]
 
-        if os.getenv('CI') == 'true' and os.getenv('TRAVIS') == 'true':
-            # On the current Travis CI platform (i.e. Ubuntu), this test generates the wrong
-            # result, which appears to be a PostgreSQL issue.  A bug report has been raised
-            # with PostgreSQL: https://www.postgresql.org/message-id/16469-11c82a64f17f51f4%40postgresql.org
-            # Nevertheless, the result is predictable so we will still test for that incorrect value.
-            # This ensures the build passes and if this behavior ever changes, we will know about it.
-            self.assertEqual(result, v.encode('utf-8').decode('latin-1'))
-        else:
-            self.assertEqual(result, v)
+        self.assertEqual(result, v)
 
     def test_cursor_messages(self):
         """
