@@ -1764,8 +1764,8 @@ class SqlServerTestCase(unittest.TestCase):
         result = self.cursor.execute("select s from t1").fetchone()[0]
 
         self.assertEqual(result, v)
-        
-    def test_tvp(self):
+
+    def _test_tvp(self, diff_schema):
         # https://github.com/mkleehammer/pyodbc/issues/290
         #
         # pyodbc supports queries with table valued parameters in sql server
@@ -1775,18 +1775,36 @@ class SqlServerTestCase(unittest.TestCase):
             warn('FREETDS_KNOWN_ISSUE - test_tvp: test cancelled.')
             return
 
+        procname = 'SelectTVP'
+        typename = 'TestTVP'
+
+        if diff_schema:
+            schemaname = 'myschema'
+            procname = schemaname + '.' + procname
+            typenameonly = typename
+            typename = schemaname + '.' + typename
+
         # (Don't use "if exists" since older SQL Servers don't support it.)
         try:
-            self.cursor.execute("drop procedure SelectTVP")
+            self.cursor.execute("drop procedure " + procname)
         except:
             pass
         try:
-            self.cursor.execute("drop type TestTVP")
+            self.cursor.execute("drop type " + typename)
         except:
             pass
+        if diff_schema:
+            try:
+                self.cursor.execute("drop schema " + schemaname)
+            except:
+                pass
         self.cursor.commit()
         
-        query = "CREATE TYPE TestTVP AS TABLE("\
+        if diff_schema:
+            self.cursor.execute("CREATE SCHEMA myschema")
+            self.cursor.commit()
+
+        query = "CREATE TYPE %s AS TABLE("\
                 "c01 VARCHAR(255),"\
                 "c02 VARCHAR(MAX),"\
                 "c03 VARBINARY(255),"\
@@ -1798,11 +1816,11 @@ class SqlServerTestCase(unittest.TestCase):
                 "c09 BIGINT,"\
                 "c10 FLOAT,"\
                 "c11 NUMERIC(38, 24),"\
-                "c12 UNIQUEIDENTIFIER)"
+                "c12 UNIQUEIDENTIFIER)" % typename
 
         self.cursor.execute(query)
         self.cursor.commit()
-        self.cursor.execute("CREATE PROCEDURE SelectTVP @TVP TestTVP READONLY AS SELECT * FROM @TVP;")
+        self.cursor.execute("CREATE PROCEDURE %s @TVP %s READONLY AS SELECT * FROM @TVP;" % (procname, typename))
         self.cursor.commit()
 
         long_string = ''
@@ -1863,7 +1881,10 @@ class SqlServerTestCase(unittest.TestCase):
         success = True
 
         try:
-            result_array = self.cursor.execute("exec SelectTVP ?",[param_array]).fetchall()
+            p1 = [param_array]
+            if diff_schema:
+                p1 = [ [ typenameonly, schemaname ] + param_array ]
+            result_array = self.cursor.execute("exec %s ?" % procname, p1).fetchall()
         except Exception as ex:
             print("Failed to execute SelectTVP")
             print("Exception: [" + type(ex).__name__ + "]" , ex.args)
@@ -1877,7 +1898,10 @@ class SqlServerTestCase(unittest.TestCase):
                         success = False
 
         try:
-            result_array = self.cursor.execute("exec SelectTVP ?", [[]]).fetchall()
+            p1 = [[]]
+            if diff_schema:
+                p1 = [ [ typenameonly, schemaname ] + [] ]
+            result_array = self.cursor.execute("exec %s ?" % procname, p1).fetchall()
             self.assertEqual(result_array, [])
         except Exception as ex:
             print("Failed to execute SelectTVP")
@@ -1885,7 +1909,27 @@ class SqlServerTestCase(unittest.TestCase):
             success = False
 
         self.assertEqual(success, True)
-        
+
+    def test_columns(self):
+        self.cursor.execute(
+            """
+            create table t1(n int, d datetime, c nvarchar(100))
+            """)
+
+        self.cursor.columns(table='t1')
+        names = {row.column_name for row in self.cursor.fetchall()}
+        assert names == {'n', 'd', 'c'}, 'names=%r' % names
+
+        self.cursor.columns(table='t1', column='c')
+        row = self.cursor.fetchone()
+        assert row.column_name == 'c'
+
+    def test_tvp(self):
+        self._test_tvp(False)
+
+    def test_tvp_diffschema(self):
+        self._test_tvp(True)
+
 def main():
     from optparse import OptionParser
     parser = OptionParser(usage=usage)
